The time series of output gap (x), inflation (pi) and interest rate (r) are taken from the FRED database and transformed as in Herwartz & Ploedt (2016). The trivariate time series model is commonly used to analyze monetary policy shocks.
Quarterly observations from 1965Q1 to 2008Q3:
| x | Percentage log-deviation of real GDP wrt the estimate of potential output by the Congressional Budget Office |
| pi | Annualized quarter-on-quarter growth of the GDP deflator |
| i | Interest rate on Federal funds |
A more detailed description of the data and a corresponding VAR model implementation can be found in Herwartz & Ploedt (2016).
USAA data.frame containing 174 observations on 3 variables.